@@ -48,6 +48,7 @@ Options::Options ()
   audio_output = NULL;
   print_visualization_list = FALSE;
   visualization = NULL;
+  skip = 0;
 
   string default_audio_output = ConfigFile::the().audio_output();
   if (default_audio_output != "")
@@ -87,6 +88,8 @@ Options::parse (int argc, char **argv)
       "set visualization plugin to use for audio playback", "<plugin_name>"},
     {"visualization-list", 'V', 0, G_OPTION_ARG_NONE, &instance->print_visualization_list,
       "show available visualization plugins", NULL },
+    {"skip", 'k', 0, G_OPTION_ARG_DOUBLE, &instance->skip,
+      "Skip the first 'n' seconds", "<n>"},
     {"quiet", 'q', 0, G_OPTION_ARG_NONE, &instance->quiet,
       "don't display any messages", NULL},
     {G_OPTION_REMAINING, '\0', 0, G_OPTION_ARG_FILENAME_ARRAY, &instance->uris, "Movies to play", NULL},
